@@ -40,8 +40,7 @@ class Ignore(object):
     
 
     def __init__(self, ignore):
-        self.match = [ i.strip() for i in ignore.split(',')
-                       if i.strip() ]
+        self.match = ignore.split()
 
     def __call__(self, request, data):
         _files = []
@@ -58,11 +57,11 @@ class All(object):
     """
     only pass files of a certain pattern; 
     the inverse of ignore
+    calling all with no arguments means only files with descriptions are used
     """
     
     def __init__(self, pattern):
-        self.match = [ i.strip() for i in pattern.split(',')
-                       if i.strip() ]
+        self.match = pattern.split()
         
 
     def __call__(self, request, data):
@@ -108,6 +107,22 @@ class TitleDescription(FormatterBase):
                 f['title'] = f['description']
                 f['description'] = None
 
+class CSS(object):
+    """specify CSS"""
+
+    def __init__(self, arg):
+        self.css = arg.split()
+    def __call__(self, request, data):
+        data['stylesheets'] = self.css
+
+class Include(object):
+    """include a file at the top of the body"""
+
+    def __init__(self, arg):
+        self.include = arg
+    def __call__(self, request, data):
+        data['include'] = self.include
+
         
 def formatters():
     formatters = {}
